@@ -227,6 +227,16 @@ void RGPackageStatus::initPixbufs()
          std::cerr << "Warning, failed to load: " << filename << std::endl;
       g_free(filename);
    }
+
+   filename = g_strdup_printf("../pixmaps/package-supported.png");
+   if (!FileExists(filename)) {
+      g_free(filename);
+      filename = SYNAPTIC_PIXMAPDIR "package-supported.png";
+   }
+   supportedPix = gdk_pixbuf_new_from_file(filename, NULL);
+   if (supportedPix == NULL)
+      std::cerr << "Warning, failed to load: " << filename << std::endl;
+   g_free(filename);
 }
 
 // class that finds out what do display to get user
@@ -244,6 +254,14 @@ GdkColor *RGPackageStatus::getBgColor(RPackage *pkg)
    return StatusColors[getStatus(pkg)];
 }
 
+GdkPixbuf *RGPackageStatus::getSupportedPix(RPackage *pkg)
+{
+   if(isSupported(pkg))
+      return supportedPix;
+   else
+      return NULL;
+}
+
 GdkPixbuf *RGPackageStatus::getPixbuf(RPackage *pkg)
 {
    return StatusPixbuf[getStatus(pkg)];
